/** **********************************************************************
 *  Class used to represent Defglobals.
 *
 * $Id$
 * (C) 1998 E.J. Friedman-Hill and the Sandia Corporation
 ********************************************************************** */

package jess;

import java.util.*;


public class Defglobal implements Resetable
{
  
  private Rete m_engine;
  private Binding m_binding;
  
  /**
    Constructor.
    */

  Defglobal(Rete engine, String name, Value val)
  {
    m_binding = new Binding(name, val);
    m_engine = engine;
  }
  
  /**
    Possibly reenter myself into engine, but only if the engine thinks it's
    appropriate!
    */

  public void reset() throws ReteException
  {
    if (m_engine.getResetGlobals())
      {
        Value v = m_binding.m_val;
        if (v.type() == RU.FUNCALL)
          {
            Context gc = m_engine.globalContext().push();
            Funcall vv = gc.expandAction(v.funcallValue());
            v = Funcall.execute(vv, gc);
            gc.pop();                        
          }
        m_engine.globalContext().addGlobalBinding(m_binding.m_name, v);   
      }        
  }
  
  public String name() { return m_binding.m_name; }

  /**
    Describe myself
    */

  public String toString()
  {
    StringBuffer sb = new StringBuffer(100);
    sb.append("[Defglobal: ");
    sb.append(m_binding);
    sb.append("]");
    return sb.toString(); 
  }
  
}

