/** **********************************************************************
 * Main.java
 * A command-line interface for Jess
 *
 * $Id$
 * (C) 1998 E.J. Friedman-Hill and the Sandia Corporation
********************************************************************** */

package jess;

import java.io.*;

public class Main
{
  public static void main(String[] argv) 
  {
    NullDisplay nd = new NullDisplay();
    Rete rete = new Rete(nd);        

    // **********************************************************************
    // Process any command-line switches
    int argIdx = 0;
    boolean doLogo = true;
    if (argv.length > 0 && "-nologo".equals(argv[argIdx]))
      {
        doLogo = false;
        argIdx++;
      }

    // **********************************************************************
    // Print banner
    if (doLogo)
      {
        System.out.println("\nJess, the Java Expert System Shell");
        System.out.println("Copyright (C) 1998 E.J. Friedman Hill"
                           + " and the Sandia Corporation");
        try
          {
            rete.executeCommand("(printout t (jess-version-string) crlf crlf)");
          } 
        catch(ReteException re) {}
      }
        
        
    // **********************************************************************
    // Open a file if requested
    InputStream fis = System.in;
    String name = argv.length <= argIdx ? null : argv[argIdx];

    try
      {
        if (name != null)
          fis = new FileInputStream(name);
      }
    catch (IOException ioe) 
      {
        rete.errStream().println("File not found or cannot open file:" +
                                 ioe.getMessage());
        System.exit(0);
      }

    // **********************************************************************
    // Load in optional packages, but don't fail if any are missing.
    String [] packages = { "jess.StringFunctions",
                           "jess.PredFunctions",
                           "jess.MultiFunctions", 
                           "jess.MiscFunctions",
                           "jess.MathFunctions",
                           "jess.BagFunctions",
                           "jess.reflect.ReflectFunctions",
                           "jess.view.ViewFunctions" };

    for (int i=0; i< packages.length; i++)
      {
        try
          {
            rete.addUserpackage((Userpackage)
                                Class.forName(packages[i]).newInstance());
          }
        catch (Throwable t) { /* Optional package not present */ }
      }

    // **********************************************************************
    // Process input from file or keyboard

    if (fis != null) 
      {
        Jesp j = new Jesp(fis, rete);
        do 
          {
            try
              {
                // Argument is 'true' for prompting, false otherwise
                j.parse(fis == System.in);
              }
            catch (ReteException re) 
              {
                re.printStackTrace(rete.errStream());
              }
            catch (ArrayIndexOutOfBoundsException ai) 
              {
                rete.errStream().println("Wrong number of args in funcall?");
                ai.printStackTrace(rete.errStream());
              }
            catch (NullPointerException npe) 
              {
                rete.errStream().println("Wrong number of args in funcall?");
                npe.printStackTrace(rete.errStream());
              }
            catch (Exception e) 
              {
                rete.errStream().println("Unexpected exception:");
                e.printStackTrace(rete.errStream());
              }
          }
        // Loop if we're using the command line
        while (fis == System.in);
      }
  }
}


