/** **********************************************************************
 *  A tiny class to hold an individual test for a 2-input node to perform
 *
 * $Id$
 * (C) 1998 E.J. Friedman-Hill and the Sandia Corporation
 ********************************************************************** */

package jess;

class Test2Multi implements Test
{

  /**
    What test to do (Test2.EQ, Test2.NEQ, etc)
   */

  int m_test;

  /**
    Which fact within a token (0,1,2...)
   */

  int m_tokenIdx;

  /**
    Which field (absolute index of slot start) from the left memory
   */

  int m_leftIdx;

  /**
    Which subfield from the left memory
   */

  int m_leftSubIdx;


  /**
    Which field (absolute index of slot start) from the right memory
   */

  int m_rightIdx;

  /**
    Which subfield from the right memory
   */

  int m_rightSubIdx;

  /**
    Constructors
    */

  Test2Multi(int test, int tokenIdx, int leftIdx, 
             int leftSubIdx, int rightIdx, int rightSubIdx)
  {
    m_test = test;
    m_tokenIdx = tokenIdx;
    m_rightIdx = rightIdx;
    m_rightSubIdx = rightSubIdx;
    m_leftIdx = leftIdx;
    m_leftSubIdx = leftSubIdx;
  }

  public boolean equals(Object tt)
  {
    if (! (tt instanceof Test2Multi))
      return false;

    Test2Multi t = (Test2Multi) tt;

    return  (m_test == t.m_test &&
             m_tokenIdx == t.m_tokenIdx &&
             m_rightIdx == t.m_rightIdx &&
             m_leftIdx == t.m_leftIdx &&
             m_rightSubIdx == t.m_rightSubIdx &&
             m_leftSubIdx == t.m_leftSubIdx);
  }

  public boolean doTest(Token lt, ValueVector rf, EvalCache c, Rete engine)
       throws ReteException
  {
    ValueVector lf = lt.fact(m_tokenIdx);
    
    if (lf == null)
      return true;
    
    Value v1;
    ValueVector slot;
    
    if (m_leftSubIdx != -1)  // i.e., first variable is in a multislot
      v1 = lf.get(m_leftIdx).listValue().get(m_leftSubIdx);
    else 
      v1 = lf.get(m_leftIdx);
    
    boolean retval;

    if (m_rightSubIdx != -1)  // i.e., first variable is in a multislot
      retval = v1.equals(rf.get(m_rightIdx).listValue().get(m_rightSubIdx));
    else 
      retval = v1.equals(rf.get(m_rightIdx));
    
    switch (m_test)
      {
      case EQ:
        if (!retval) return false;
        break;
        
      case NEQ:
        if (retval) return false;
        break;
      }
    return true;
  }

  public String toString()
  {
    StringBuffer sb = new StringBuffer(100);
    sb.append("[Test2: test=");
    sb.append(m_test == NEQ ? "NEQ" : "EQ");
    sb.append(";tokenIdx=");
    sb.append(m_tokenIdx);
    sb.append(";leftIdx=");
    sb.append(m_leftIdx);
    sb.append(";leftSubIdx=");
    sb.append(m_leftSubIdx);
    sb.append(";rightIdx=");
    sb.append(m_rightIdx);
    sb.append(";rightSubIdx=");
    sb.append(m_rightSubIdx);
    sb.append("]");

    return sb.toString();
  }

}


